# Copyright (c) 2000-2010, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

%define namedversion 2.3-M1

Name:           geoapi
Version:        2.3
Release:        0.M1.1%{?dist}
Summary:        Java APIs por geospatial applications

Group:          Development/Libraries
License:        BSD-style
URL:            http://geoapi.sourceforge.net/

Source0:        %{name}-%{namedversion}.tgz
#svn export http://geoapi.svn.sourceforge.net/svnroot/geoapi/tags/2.3-M8 geoapi-2.3-M8
#tar czf geoapi-2.3-M8.tgz geoapi-2.3-M8/


Source1:       %{name}-settings.xml
Source2:       %{name}-jpp-depmap.xml 
Patch0:        geoapi-pom.patch
#Patch1:        geoapi-pending-pom.patch

BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

BuildRequires:  jpackage-utils >= 0:1.7.5
BuildRequires:  java-devel >= 1.6.0
BuildRequires:  maven2 >= 2.0.8
BuildRequires:  maven2-plugin-source
BuildRequires:  maven-surefire-maven-plugin
BuildRequires:  maven-surefire-provider-junit4
BuildRequires:  apache-commons-parent
BuildRequires:  jsr275

Requires:  java >= 1.6.0
Requires:  jpackage-utils >= 0:1.7.5
Requires:  jsr275

Requires(post):    jpackage-utils >= 0:1.7.5
Requires(postun):  jpackage-utils >= 0:1.7.5

BuildArch:      noarch

%description
GeoAPI provides a set of Java language programming 
interfaces for geospatial applications.
The interfaces developed by the GeoAPI project include many
of the data structures and manipulation methods needed for
geographic information system applications. In a series of
independent packages, GeoAPI defines a core set of
interfaces for metadata handling, for geodetic referencing,
projection and conversion, for the handling of georeferenced
imagery, for the construction and manipulation of vector
geometry and tological data structures, and for the
description and use of geospatial 'feature' entities. Beyond
this core, GeoAPI further defines interfaces for data access
and storage including sophisticated filter queries, and for
display.

The GeoAPI interfaces closely follow the abstract model and
concrete specifications published collaboratively by the
International Organization for Standardization (ISO) in its
19100 series of documents and the Open Geospatial Consortium
(OGC) in its abstract and implementation specifications.
GeoAPI provides an interpretation and adaptation of these
standards to match the expectations of Java programmers.
These standards provide GeoAPI with the richness which comes
from the expertise of the specification writers. Clients
benefit from the potential for inter-operability which comes
from using a well defined, standardized data model.
Implementors benefit from having a pre-defined set of well
considered, formal boundaries to modularize their development
work.

The GeoAPI interfaces provide a layer which separates client
code, which would call the API, from library code, which
implements the API. These interfaces are not an implementation.
This follows a similar pattern to the well known JDBC API which
provides a standardized interface to databases. Clients can use
the JDBC API without concern for the particular implementation
which they will use. Various groups have implemented different
subsets of GeoAPI, see the list of known implementations for
details.

%package javadoc 
Summary:        Javadocs for %{name} 
Group:          Documentation 
Requires:       %{name} = %{version}-%{release} 
 
%description javadoc 
%{summary}. 

%prep
%setup -q -n %{name}-%{namedversion}
cp -p %{SOURCE1} settings.xml
sed -i -e "s|<url>__JPP_URL_PLACEHOLDER__</url>|<url>file://`pwd`/.m2/repository</url>|g" settings.xml
sed -i -e "s|<url>__JAVADIR_PLACEHOLDER__</url>|<url>file://`pwd`/external_repo</url>|g" settings.xml
sed -i -e "s|<url>__MAVENREPO_DIR_PLACEHOLDER__</url>|<url>file://`pwd`/.m2/repository</url>|g" settings.xml
sed -i -e "s|<url>__MAVENDIR_PLUGIN_PLACEHOLDER__</url>|<url>file:///usr/share/maven2/plugins</url>|g" settings.xml
%patch0 -b .sav
#%patch1 -b .sav
mkdir external_repo
ln -s %{_javadir} external_repo/JPP

#
#mkdir -p geoapi-pending/src/main/resources/org/opengis/metadata/
#cp geoapi/src/main/resources/org/opengis/metadata/Descriptions.properties geoapi-pending/src/main/resources/org/opengis/metadata/

%build
export MAVEN_REPO_LOCAL=$(pwd)/.m2/repository
mkdir -p ${MAVEN_REPO_LOCAL}
export MAVEN_OPTS="-Dmaven2.jpp.mode=true -Dmaven2.jpp.depmap.file=%{SOURCE2} -Dmaven.repo.local=${MAVEN_REPO_LOCAL} -Djava.awt.headless=true -Daggregate=true"
%{_bindir}/mvn-jpp \
        -e \
        -s $(pwd)/settings.xml \
        install

%{_bindir}/mvn-jpp \
        -e \
        -s $(pwd)/settings.xml \
        javadoc:javadoc

%install
%__rm -rf %{buildroot}

# jar
%__mkdir_p %{buildroot}%{_javadir}/%{name}
%__install -m 644 tools/target/tools-%{namedversion}.jar %{buildroot}%{_javadir}/%{name}/tools-%{version}.jar
%__install -m 644 geoapi/target/geoapi-%{namedversion}.jar %{buildroot}%{_javadir}/%{name}/geoapi-%{version}.jar
%__install -m 644 geoapi-pending/target/geoapi-pending-%{namedversion}.jar %{buildroot}%{_javadir}/%{name}/geoapi-pending-%{version}.jar
%__install -m 644 examples/target/examples-%{namedversion}.jar %{buildroot}%{_javadir}/%{name}/examples-%{version}.jar
%__install -m 644 conformance/target/conformance-%{namedversion}.jar %{buildroot}%{_javadir}/%{name}/conformance-%{version}.jar
(cd %{buildroot}%{_javadir}/%{name} && for jar in *-%{version}*; do \
%__ln_s ${jar} ${jar/-%{version}/}; done)

# poms
%__mkdir_p %{buildroot}%{_datadir}/maven2/poms
%__install -m 644 pom.xml \
               $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP.%{name}-parent.pom
%add_to_maven_depmap org.opengis parent %{version} JPP/%{name} parent
%__install -m 644 tools/pom.xml \
               $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP.%{name}-tools.pom
%add_to_maven_depmap org.opengis tools %{version} JPP/%{name} tools
%__install -m 644 geoapi/pom.xml \
               $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP.%{name}-geoapi.pom
%add_to_maven_depmap org.opengis geoapi %{version} JPP/%{name} geoapi
%__install -m 644 geoapi-pending/pom.xml \
               $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP.%{name}-geoapi-pending.pom
%add_to_maven_depmap org.opengis geoapi-pending %{version} JPP/%{name} geoapi-pending
%__install -m 644 examples/pom.xml \
               $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP.%{name}-examples.pom
%add_to_maven_depmap org.opengis examples %{version} JPP/%{name} examples
%__install -m 644 conformance/pom.xml \
               $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP.%{name}-conformance.pom
%add_to_maven_depmap org.opengis conformance %{version} JPP/%{name} conformance

# javadoc 
%__mkdir_p %{buildroot}%{_javadocdir}/%{name}-%{version} 
%__cp -a target/site/apidocs/* \
               %{buildroot}%{_javadocdir}/%{name}-%{version}/
%__ln_s %{name}-%{version} %{buildroot}%{_javadocdir}/%{name} 

%clean
%__rm -rf %{buildroot}

%post
%update_maven_depmap

%postun
%update_maven_depmap

%files
%defattr(-,root,root,-)
%dir %{_javadir}/%{name}
%{_javadir}/%{name}/*.jar
%{_datadir}/maven2/poms/*
%{_mavendepmapfragdir}/*

%files javadoc 
%defattr(-,root,root,-) 
%{_javadocdir}/%{name}-%{version} 
%{_javadocdir}/%{name} 

%changelog
* Thu Oct 14 2010 Ralph Apel <r.apel@r-apel.de> 2.3-0.M1.1
- First release

